import * as RRLIB from '../../js/modules/rrlib.js'
import PalLib from '../../js/modules/pallib.js'

class PageManager {
	constructor() {
		this.ros = new RRLIB.Ros({
			host: 'http://' + window.location.hostname
		});
		this.pal_lib = new PalLib();
		this.user_input = new RRLIB.Topic({
			ros: this.ros,
			name: 'user_input'
		});
		this.question = "Do you want to watch a film now?"; // TODO: question text
		this.answers_list = ["Yes", "No"]; // TODO: set answers buttons list
	}

	init() {
		this.pal_lib.init();
		this.setWebText();
	}

	setWebText() {
		// inject question text into HTML
		$("#question").html(this.question); 
		// inject button HTML element from answers_list
		for (let [answer_index, answer_value] of this.answers_list.entries()) {
			$("#answers_list").append('<div class="button-item" id="answer_' + answer_index + '">' +
										answer_value + '</div>');
		}	
	}
	touchInput(activity) {
		this.user_input.publish({
			action: activity,
			args: [{
				key: '',
				value: ''
			}]
		});

	}
};

let page_manager = new PageManager();

$(document).ready(function() {
    page_manager.init();
    /* 
	===== FUNCTIONS =====
    */
    // Exit btn
    $("#exit_btn").on("touchend", () => {
        page_manager.touchInput("exit");
        $("#exit_btn").removeClass("exit-button-hover");
    });
    // Answer buttons click
    $(".button-item").on("touchend", function(){
    	let touched_btn_index = $(this).attr("id").slice(-1);
    	let chosen_answer = page_manager.answers_list[touched_btn_index];
    	console.log(chosen_answer);
    	// After answer button was clicked
    	page_manager.touchInput(chosen_answer);
    });
    /*
	===== HOVER STYLES =====
    */
    // Exit btn hover
    $("#exit_btn").on("touchstart", () => {
        $("#exit_btn").addClass("exit-button-hover");
    });
    // Clear all buttons state
    $("body").on("touchstart", () => {
    	$(".button-item").removeClass("button-hover");
    });
    // Answer button active
    $(".button-item").on("touchstart", function(event) {
    	event.stopPropagation();
    	$(".button-item").removeClass("button-hover");
    	$(this).addClass("button-hover");
    });
});
