/** PALLib version intended for off-line use */
class PalLib {
	/**
		* Create a PALLib object. It is recomended to use a single
		* object throught the page.
		*/
	constructor() {
		console.log("Using offline PALLib SDK");
		this.initialized = false;
	}

	/**
		* PALLib oject should be initialized on page load
		*/
	init() {
		console.log("Init PALLib SDK");
		this.initialized = true;
	}

	/**
		*  Execute a named motion and execute a callback after it is finished
		* @param {string} motion - Name of the motion to be executed
		* @param {number} tracking_interval - Time at which to check the status of the motion, in ms. (500 recommended)
		* @param {function} end_cb - Function to call at the end of the motion, receives status of the motion
		* @param {function} goal_cb - Function to call when the motion is accepted by the robot, receives internal ID. Optional.
		*/
	executeAndTrackMotion(motion, tracking_interval, end_cb, goal_cb) {
		if (!this.initialized) {
			console.log("Called without initializing, failing");
			return;
		}
		window.setTimeout(() => {
			if (goal_cb !== undefined)
				goal_cb("goal_id");
			console.log("Goal accepted by the robot. Starting motion " + motion);
		}, 100);

		let timeout = tracking_interval * (Math.floor(Math.random() * 10) + 1); // Randomize time to end
		window.setTimeout(() => {
			end_cb("SUCCEEDED");
			console.log("Motion " + motion + " ended.");
		}, timeout);
	}

	/**
		*  Say a sentence in a language, and execute a callback when it is finished
		* @param {string} text - Sentence to be said by the robot
		* @param {string} lang - Language code to be used
		* @param {number} tracking_interval - Time at which to check the status of the speech, in ms. (500 recommended)
		* @param {function} end_cb - Function to call at the end of the speech, receives status of the speech
		* @param {function} goal_cb - Function to call when the speech is accepted by the robot, receives internal ID. Optional.
		*/
	sayAndTrack(text, lang, tracking_interval, end_cb, goal_cb) {
		if (!this.initialized) {
			console.log("Called without initializing, failing");
			return;
		}

		window.setTimeout(() => {
			if (goal_cb !== undefined)
				goal_cb("goal_id");
			console.log("Goal accepted by the robot. Starting speech: " + text);

			if (lang == "es_ES")
				console.log("In spanish");
			else if (lang == "ca_ES")
				console.log("In catalan");
			else if (lang == "en_GB")
				console.log("In english");
			else
				console.log("In unknown language, defaulting to english");
		}, 100);

		let timeout = tracking_interval * (Math.floor(Math.random() * 10) + 1); // Randomize time to end
		window.setTimeout(() => {
			end_cb("SUCCEEDED");
			console.log("Speech ended.");
		}, timeout);
	}
}

export default PalLib